# HiveNetAssemble

[中文版本](README_zh.md)

Hivenetassemble is a set of Python libraries convenient for developers to use. It aims to enable developers to realize the most commonly used functions in the simplest way, improve development efficiency, and pay attention to specific function logic rather than specific technical implementation.
The project is transformed from the HiveNetLib project. The reason is that the HiveNetLib project adopts the method of single library, resulting in more and more dependence, and the whole library is becoming more and more bloated. Therefore, this project is created to separate the functions in HiveNetLib into an independent library to reduce the complexity of maintenance and use of the whole project.

docs: https://hivenetassemble.readthedocs.io/zh_CN/latest/

The project is under building ...
